import { addComponent, defineNuxtModule, createResolver, addPlugin } from '@nuxt/kit';
import { Components } from 'bootstrap-vue-next';

const useComponents = () => {
  Object.keys(Components).forEach((name) => {
    addComponent({
      name,
      export: name,
      filePath: "bootstrap-vue-next"
    });
  });
};

const module = defineNuxtModule({
  meta: {
    name: "bootstrap-vue-next",
    configKey: "bootstrapVueNext",
    compatibility: {
      nuxt: "^3.0.0",
      bridge: false
    }
  },
  defaults: {
    directives: true,
    composables: true
  },
  setup(options, nuxt) {
    const resolver = createResolver(import.meta.url);
    const normalizedcomposables = typeof options.composables === "boolean" ? { all: options.composables } : options.composables;
    nuxt.options.build.transpile.push(resolver.resolve("./runtime"));
    nuxt.options.css.push("bootstrap-vue-next/dist/bootstrap-vue-next.css");
    useComponents();
    if (normalizedcomposables.createBreadcrumb || normalizedcomposables.useBreadcrumb) {
      addPlugin(resolver.resolve("./runtime/breadcrumb"));
    }
  }
});

export { module as default };
